@@ -16,6 +16,7 @@
 #include <kdesktopfile.h>
 #include <qtemporarydir.h>
 
+#include <kauthorized.h>
 #include <kconfiggroup.h>
 #include <kconfigwatcher.h>
 #include <ksharedconfig.h>
@@ -116,9 +117,15 @@ void KConfigTest::initTestCase()
 
     KConfig sc(s_kconfig_test_subdir);
 
-    KConfigGroup cg(&sc, "AAA");
+    KConfigGroup cg(&sc, "AAA"); // deleted later by testDelete
     cg.writeEntry("stringEntry1", s_string_entry1, KConfig::Persistent | KConfig::Global);
-    cg.deleteEntry("stringEntry2", KConfig::Global);
+
+    cg = KConfigGroup(&sc, "GlobalGroup");
+    cg.writeEntry("globalEntry", s_string_entry1, KConfig::Persistent | KConfig::Global);
+    cg.deleteEntry("globalEntry2", KConfig::Global);
+
+    cg = KConfigGroup(&sc, "LocalGroupToBeDeleted"); // deleted later by testDelete
+    cg.writeEntry("stringEntry1", s_string_entry1);
 
     cg = KConfigGroup(&sc, "Hello");
     cg.writeEntry("boolEntry1", s_bool_entry1);
@@ -339,16 +346,16 @@ void KConfigTest::testSimple()
         QVERIFY(!group.contains(QChar(0x1d)));
     }
 
-    KConfigGroup sc3(&sc2, "AAA");
+    KConfigGroup sc3(&sc2, "GlobalGroup");
 
-    QVERIFY(sc3.hasKey("stringEntry1")); // from kdeglobals
-    QVERIFY(!sc3.isEntryImmutable("stringEntry1"));
-    QCOMPARE(sc3.readEntry("stringEntry1"), s_string_entry1);
+    QVERIFY(sc3.hasKey("globalEntry")); // from kdeglobals
+    QVERIFY(!sc3.isEntryImmutable("globalEntry"));
+    QCOMPARE(sc3.readEntry("globalEntry"), s_string_entry1);
 
-    QVERIFY(!sc3.hasKey("stringEntry2"));
-    QCOMPARE(sc3.readEntry("stringEntry2", QStringLiteral("bla")), QStringLiteral("bla"));
+    QVERIFY(!sc3.hasKey("globalEntry2"));
+    QCOMPARE(sc3.readEntry("globalEntry2", QStringLiteral("bla")), QStringLiteral("bla"));
 
-    QVERIFY(!sc3.hasDefault("stringEntry1"));
+    QVERIFY(!sc3.hasDefault("globalEntry"));
 
     sc3 = KConfigGroup(&sc2, "Hello");
     QCOMPARE(sc3.readEntry("Test", QByteArray()), QByteArray(s_utf8bit_entry));
@@ -799,19 +806,25 @@ void KConfigTest::testDelete()
     KConfigGroup delgr(&ct, "Nested Group 3");
     QVERIFY(delgr.exists());
     QVERIFY(ct.hasGroup("Nested Group 3"));
+    QVERIFY(ct.groupList().contains(QStringLiteral("Nested Group 3")));
     delgr.deleteGroup();
     QVERIFY(!delgr.exists());
     QVERIFY(!ct.hasGroup("Nested Group 3"));
-    QVERIFY(ct.groupList().contains(QStringLiteral("Nested Group 3")));
+    QVERIFY(!ct.groupList().contains(QStringLiteral("Nested Group 3")));
 
     KConfigGroup ng(&ct, "Nested Group 2");
     QVERIFY(sc.hasGroup("Complex Types"));
+    QVERIFY(sc.groupList().contains(QStringLiteral("Complex Types")));
     QVERIFY(!sc.hasGroup("Does not exist"));
+    QVERIFY(ct.hasGroup("Nested Group 1"));
+    QVERIFY(ct.groupList().contains(QStringLiteral("Nested Group 1")));
     sc.deleteGroup("Complex Types");
     QCOMPARE(sc.group("Complex Types").keyList().count(), 0);
     QVERIFY(!sc.hasGroup("Complex Types")); // #192266
     QVERIFY(!sc.group("Complex Types").exists());
+    QVERIFY(!sc.groupList().contains(QStringLiteral("Complex Types")));
     QVERIFY(!ct.hasGroup("Nested Group 1"));
+    QVERIFY(!ct.groupList().contains(QStringLiteral("Nested Group 1")));
 
     QCOMPARE(ct.group("Nested Group 1").keyList().count(), 0);
     QCOMPARE(ct.group("Nested Group 2").keyList().count(), 0);
@@ -822,7 +835,9 @@ void KConfigTest::testDelete()
     QVERIFY(sc.entryMap(QStringLiteral("Complex Types")).isEmpty());
     QVERIFY(sc.entryMap(QStringLiteral("AAA")).isEmpty());
     QVERIFY(!sc.entryMap(QStringLiteral("Hello")).isEmpty()); // not deleted group
-    QVERIFY(sc.entryMap(QStringLiteral("FooBar")).isEmpty()); // inexistant group
+    QVERIFY(sc.entryMap(QStringLiteral("FooBar")).isEmpty()); // inexistent group
+
+    KConfigGroup(&sc, "LocalGroupToBeDeleted").deleteGroup();
 
     QVERIFY(cg.sync());
     // Check what happens on disk
@@ -832,7 +847,8 @@ void KConfigTest::testDelete()
     QVERIFY(!lines.contains("[Complex Types][Nested Group 1]\n"));
     QVERIFY(!lines.contains("[Complex Types][Nested Group 2]\n"));
     QVERIFY(!lines.contains("[Complex Types][Nested Group 2.1]\n"));
-    QVERIFY(!lines.contains("[AAA]\n"));
+    QVERIFY(!lines.contains("[LocalGroupToBeDeleted]\n"));
+    QVERIFY(lines.contains("[AAA]\n")); // deleted from kconfigtest, but present in kdeglobals, so [$d]
     QVERIFY(lines.contains("[Hello]\n")); // a group that was not deleted
 
     // test for entries that are marked as deleted when there is no default
@@ -844,10 +860,11 @@ void KConfigTest::testDelete()
 
     int count = 0;
     const QList<QByteArray> listLines = readLines();
-    for (const QByteArray &item : listLines)
+    for (const QByteArray &item : listLines) {
         if (item.startsWith("devices|")) { // krazy:exclude=strings
             ++count;
         }
+    }
     QCOMPARE(count, 2);
     cg.deleteEntry("devices|manual|/mnt/ipod");
     QVERIFY(cf.sync());
@@ -960,6 +977,7 @@ void KConfigTest::testCascadingWithLocale()
 #ifdef Q_XDG_PLATFORM
     QTemporaryDir middleDir;
     QTemporaryDir globalDir;
+    const QByteArray oldConfigDirs = qgetenv("XDG_CONFIG_DIRS");
     qputenv("XDG_CONFIG_DIRS", qPrintable(middleDir.path() + QLatin1Char(':') + globalDir.path()));
 
     const QString globalConfigDir = globalDir.path() + QLatin1Char('/') + s_test_subdir;
@@ -998,7 +1016,8 @@ void KConfigTest::testCascadingWithLocale()
     QCOMPARE(group.readEntry("FromGlobal"), QStringLiteral("vrai"));
     QCOMPARE(group.readEntry("FromLocal"), QStringLiteral("vrai"));
     QCOMPARE(group.readEntry("Name"), QStringLiteral("FR"));
-    QCOMPARE(group.readEntry("Other"), QStringLiteral("English Only")); // Global_FR is locally overriden
+    QCOMPARE(group.readEntry("Other"), QStringLiteral("English Only")); // Global_FR is locally overridden
+    qputenv("XDG_CONFIG_DIRS", oldConfigDirs);
 #endif
 }
 
@@ -1045,7 +1064,7 @@ void KConfigTest::testMerge()
               << "entry[fr]=French\n";
         QFile file(m_testConfigDir + QLatin1String("/mergetest"));
         file.open(QIODevice::ReadOnly | QIODevice::Text);
-        for (const QByteArray &line : qAsConst(lines)) {
+        for (const QByteArray &line : std::as_const(lines)) {
             QCOMPARE(line, file.readLine());
         }
     }
@@ -1112,7 +1131,7 @@ void KConfigTest::testOptionOrder()
 
         QFile file(m_testConfigDir + QLatin1String("/doubleattrtest"));
         file.open(QIODevice::ReadOnly | QIODevice::Text);
-        for (const QByteArray &line : qAsConst(lines)) {
+        for (const QByteArray &line : std::as_const(lines)) {
             QCOMPARE(line, file.readLine());
         }
     }
@@ -1353,7 +1372,8 @@ static void ageTimeStamp(const QString &path, int nsec)
 
 void KConfigTest::testWriteOnSync()
 {
-    QDateTime oldStamp, newStamp;
+    QDateTime oldStamp;
+    QDateTime newStamp;
     KConfig sc(s_kconfig_test_subdir, KConfig::IncludeGlobals);
 
     // Age the timestamp of global config file a few sec, and collect it.
@@ -1400,8 +1420,9 @@ void KConfigTest::testFailOnReadOnlyFileSync()
     QVERIFY(f.setPermissions(QFileDevice::ReadOwner));
 
 #ifndef Q_OS_WIN
-    if (::getuid() == 0)
+    if (::getuid() == 0) {
         QSKIP("Root can write to read-only files");
+    }
 #endif
     cgLocal.writeEntry("someLocalString", "whatever2");
     QVERIFY(!cgLocal.sync());
@@ -1412,7 +1433,8 @@ void KConfigTest::testFailOnReadOnlyFileSync()
 
 void KConfigTest::testDirtyOnEqual()
 {
-    QDateTime oldStamp, newStamp;
+    QDateTime oldStamp;
+    QDateTime newStamp;
     KConfig sc(s_kconfig_test_subdir);
 
     // Initialize value
@@ -1710,8 +1732,57 @@ void KConfigTest::testKdeGlobals()
         const KConfigGroup generalNoGlob(&globReadNoGlob, "General");
         QCOMPARE(generalNoGlob.readEntry("testKG"), QStringLiteral("2"));
     }
+}
 
-    // TODO now use kconfigtest and writeEntry(,Global) -> should go into kdeglobals
+void KConfigTest::testLocalDeletion()
+{
+    // Prepare kdeglobals
+    {
+        KConfig glob(QStringLiteral("kdeglobals"));
+        KConfigGroup general(&glob, "OwnTestGroup");
+        general.writeEntry("GlobalKey", "DontTouchMe");
+        QVERIFY(glob.sync());
+    }
+
+    QStringList expectedKeys{QStringLiteral("LocalKey")};
+    expectedKeys.prepend(QStringLiteral("GlobalWrite"));
+
+    // Write into kconfigtest, including deleting GlobalKey
+    {
+        KConfig mainConfig(s_kconfig_test_subdir);
+        KConfigGroup mainGroup(&mainConfig, "OwnTestGroup");
+        mainGroup.writeEntry("LocalKey", QStringLiteral("LocalValue"));
+        mainGroup.writeEntry("GlobalWrite", QStringLiteral("GlobalValue"), KConfig::Persistent | KConfig::Global); // goes to kdeglobals
+        QCOMPARE(mainGroup.readEntry("GlobalKey"), QStringLiteral("DontTouchMe"));
+        mainGroup.deleteEntry("GlobalKey"); // local deletion ([$d]), kdeglobals is unchanged
+        QCOMPARE(mainGroup.readEntry("GlobalKey", "Default"), QStringLiteral("Default")); // key is gone
+        QCOMPARE(mainGroup.keyList(), expectedKeys);
+    }
+
+    // Check what ended up in kconfigtest
+    const QList<QByteArray> lines = readLines();
+    QVERIFY(lines.contains("[OwnTestGroup]\n"));
+    QVERIFY(lines.contains("GlobalKey[$d]\n"));
+
+    // Check what ended up in kdeglobals
+    {
+        KConfig globReadNoGlob(QStringLiteral("kdeglobals"), KConfig::NoGlobals);
+        const KConfigGroup generalNoGlob(&globReadNoGlob, "OwnTestGroup");
+        QCOMPARE(generalNoGlob.readEntry("GlobalKey"), QStringLiteral("DontTouchMe"));
+        QCOMPARE(generalNoGlob.readEntry("GlobalWrite"), QStringLiteral("GlobalValue"));
+        QVERIFY(!generalNoGlob.hasKey("LocalValue"));
+        QStringList expectedGlobalKeys{QStringLiteral("GlobalKey")};
+        expectedGlobalKeys.append(QStringLiteral("GlobalWrite"));
+        QCOMPARE(generalNoGlob.keyList(), expectedGlobalKeys);
+    }
+
+    // Check what we see when re-reading the config file
+    {
+        KConfig mainConfig(s_kconfig_test_subdir);
+        KConfigGroup mainGroup(&mainConfig, "OwnTestGroup");
+        QCOMPARE(mainGroup.readEntry("GlobalKey", "Default"), QStringLiteral("Default")); // key is gone
+        QCOMPARE(mainGroup.keyList(), expectedKeys);
+    }
 }
 
 void KConfigTest::testAnonymousConfig()
@@ -1834,6 +1905,47 @@ void KConfigTest::testNewlines()
 #endif
 }
 
+void KConfigTest::testMoveValuesTo()
+{
+    QTemporaryFile file;
+    QVERIFY(file.open());
+    // Prepare kdeglobals
+    {
+        KConfig glob(QStringLiteral("kdeglobals"));
+        KConfigGroup general(&glob, "TestGroup");
+        general.writeEntry("GlobalKey", "PlsDeleteMe");
+        QVERIFY(glob.sync());
+    }
+
+    KConfigGroup grp = KSharedConfig::openConfig(file.fileName())->group("TestGroup");
+
+    grp.writeEntry("test1", "first_value");
+    grp.writeEntry("test_empty", "");
+    grp.writeEntry("other", "other_value");
+    grp.writePathEntry("my_path", QStringLiteral("~/somepath"));
+    // because this key is from the global file it should be explicitly deleted
+    grp.deleteEntry("GlobalKey");
+
+    QTemporaryFile targetFile;
+    QVERIFY(targetFile.open());
+    targetFile.close();
+    KConfigGroup targetGroup = KSharedConfig::openConfig(targetFile.fileName(), KConfig::SimpleConfig)->group("MoveToGroup");
+
+    grp.moveValuesTo({"test1", "test_empty", "does_not_exist", "my_path", "GlobalKey"}, targetGroup);
+    QVERIFY(grp.config()->isDirty());
+    QVERIFY(targetGroup.config()->isDirty());
+
+    QCOMPARE(grp.keyList(), QStringList{QStringLiteral("other")});
+    QStringList expectedKeyList{QStringLiteral("my_path"), QStringLiteral("test1"), QStringLiteral("test_empty")};
+    QCOMPARE(targetGroup.keyList(), expectedKeyList);
+    QCOMPARE(targetGroup.readEntry("test1"), QStringLiteral("first_value"));
+
+    targetGroup.sync();
+    QFile targetReadFile(targetFile.fileName());
+    targetReadFile.open(QFile::ReadOnly);
+    QVERIFY(targetReadFile.readAll().contains(QByteArray("my_path[$e]=~/somepath")));
+}
+
 void KConfigTest::testXdgListEntry()
 {
     QTemporaryFile file;
@@ -1868,18 +1980,30 @@ void KConfigTest::testXdgListEntry()
 void KConfigTest::testThreads()
 {
     QThreadPool::globalInstance()->setMaxThreadCount(6);
-    QList<QFuture<void>> futures;
     // Run in parallel some tests that work on different config files,
     // otherwise unexpected things might indeed happen.
-    futures << QtConcurrent::run(this, &KConfigTest::testAddConfigSources);
-    futures << QtConcurrent::run(this, &KConfigTest::testSimple);
-    futures << QtConcurrent::run(this, &KConfigTest::testDefaults);
-    futures << QtConcurrent::run(this, &KConfigTest::testSharedConfig);
-    futures << QtConcurrent::run(this, &KConfigTest::testSharedConfig);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    const QList<QFuture<void>> futures = {
+        QtConcurrent::run(&KConfigTest::testAddConfigSources, this),
+        QtConcurrent::run(&KConfigTest::testSimple, this),
+        QtConcurrent::run(&KConfigTest::testDefaults, this),
+        QtConcurrent::run(&KConfigTest::testSharedConfig, this),
+        QtConcurrent::run(&KConfigTest::testSharedConfig, this),
+    };
+#else
+    const QList<QFuture<void>> futures = {
+        QtConcurrent::run(this, &KConfigTest::testAddConfigSources),
+        QtConcurrent::run(this, &KConfigTest::testSimple),
+        QtConcurrent::run(this, &KConfigTest::testDefaults),
+        QtConcurrent::run(this, &KConfigTest::testSharedConfig),
+        QtConcurrent::run(this, &KConfigTest::testSharedConfig),
+    };
+#endif
+
     // QEXPECT_FAIL triggers race conditions, it should be fixed to use QThreadStorage...
     // futures << QtConcurrent::run(this, &KConfigTest::testDeleteWhenLocalized);
     // futures << QtConcurrent::run(this, &KConfigTest::testEntryMap);
-    for (QFuture<void> f : qAsConst(futures)) {
+    for (QFuture<void> f : futures) {
         f.waitForFinished();
     }
 }
@@ -1966,6 +2090,21 @@ void KConfigTest::testNotify()
     QCOMPARE(otherWatcherSpy[0][1].value<QByteArrayList>(), QByteArrayList({"someGlobalEntry"}));
 }
 
+void KConfigTest::testKAuthorizeEnums()
+{
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup actionRestrictions = config->group("KDE Action Restrictions");
+    actionRestrictions.writeEntry("shell_access", false);
+    actionRestrictions.writeEntry("action/open_with", false);
+
+    QVERIFY(!KAuthorized::authorize(KAuthorized::SHELL_ACCESS));
+    QVERIFY(!KAuthorized::authorizeAction(KAuthorized::OPEN_WITH));
+    actionRestrictions.deleteGroup();
+
+    QVERIFY(!KAuthorized::authorize((KAuthorized::GenericRestriction)0));
+    QVERIFY(!KAuthorized::authorizeAction((KAuthorized::GenericAction)0));
+}
+
 void KConfigTest::testKdeglobalsVsDefault()
 {
     // Add testRestore key with global value in kdeglobals
