@@ -4,13 +4,22 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <QtTest>
 #include "kstandardshortcuttest.h"
+#include <QTest>
 
-QTEST_MAIN(KStandardShortcutTest)  // GUI needed by KAccel
+QTEST_MAIN(KStandardShortcutTest) // GUI needed by KAccel
 
 #include <kstandardshortcut.h>
 
+#ifndef Q_OS_WIN
+void initLocale()
+{
+    setenv("LC_ALL", "en_US.utf-8", 1);
+}
+
+Q_CONSTRUCTOR_FUNCTION(initLocale)
+#endif
+
 void KStandardShortcutTest::testShortcutDefault()
 {
     QCOMPARE(QKeySequence::listToString(KStandardShortcut::hardcodedDefaultShortcut(KStandardShortcut::FullScreen)), QLatin1String("Ctrl+Shift+F"));
@@ -40,8 +49,8 @@ void KStandardShortcutTest::testShortcut()
 
 void KStandardShortcutTest::testFindStdAccel()
 {
-    QCOMPARE(KStandardShortcut::find(QString("Ctrl+F")), KStandardShortcut::Find);
-    QCOMPARE(KStandardShortcut::find(QString("Ctrl+Shift+Alt+G")), KStandardShortcut::AccelNone);
+    QCOMPARE(KStandardShortcut::find(QKeySequence(Qt::CTRL | Qt::Key_F)), KStandardShortcut::Find);
+    QCOMPARE(KStandardShortcut::find(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::ALT | Qt::Key_G)), KStandardShortcut::AccelNone);
 }
 
 void KStandardShortcutTest::testFindByName()
